# Changelog

## 0.0.1-alpha.1 (2025-01-13)

Full Changelog: [v0.0.1-alpha.0...v0.0.1-alpha.1](https://github.com/ryohno/beatssdk/compare/v0.0.1-alpha.0...v0.0.1-alpha.1)

### Chores

* go live ([#1](https://github.com/ryohno/beatssdk/issues/1)) ([a616e9c](https://github.com/ryohno/beatssdk/commit/a616e9c0f60bdfa2edb7ea3f69268dfbdd1cad4d))
* update SDK settings ([#3](https://github.com/ryohno/beatssdk/issues/3)) ([325dfd2](https://github.com/ryohno/beatssdk/commit/325dfd27f6902532757a5b0d3df345d62ddbd47a))
